==> haskell-lucid-2.9.12-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lucid
version:              2.9.12
visibility:           public
id:                   lucid-2.9.12-5JcnxbQxNMf2ErO6v2Rokc
key:                  lucid-2.9.12-5JcnxbQxNMf2ErO6v2Rokc
license:              BSD-3-Clause
copyright:            2014-2017 Chris Done
maintainer:           chrisdone@gmail.com, oleg.grenrus@iki.fi
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  2df52d066fb48c8bafb3217ffaaf964e
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-8.8.1/site-local/lucid-2.9.12
library-dirs:         /usr/lib/ghc-8.8.1/site-local/lucid-2.9.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/lucid-2.9.12
hs-libraries:         HSlucid-2.9.12-5JcnxbQxNMf2ErO6v2Rokc
depends:
    base-4.13.0.0 blaze-builder-0.4.1.0-3xTNie2AGY1AnFlpxCbxSb
    bytestring-0.10.9.0 containers-0.6.2.1
    hashable-1.2.7.0-Jxai6kzZTBkIQjxJHBmP5T
    mmorph-1.1.3-JCMpsrUvhnr1NOPkDZRyaY mtl-2.2.2 text-1.2.4.0
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-9ICZg3HcXJIzoexd54oj9

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.12-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lucid
version:              2.9.12
visibility:           public
id:                   lucid-2.9.12-5B01RbvMabAKtLHMHguc39
key:                  lucid-2.9.12-5B01RbvMabAKtLHMHguc39
license:              BSD-3-Clause
copyright:            2014-2017 Chris Done
maintainer:           chrisdone@gmail.com, oleg.grenrus@iki.fi
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  cfc9473db2759fbf223f9de943546d6e
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-8.8.2/site-local/lucid-2.9.12
library-dirs:         /usr/lib/ghc-8.8.2/site-local/lucid-2.9.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/lucid-2.9.12
hs-libraries:         HSlucid-2.9.12-5B01RbvMabAKtLHMHguc39
depends:
    base-4.13.0.0 blaze-builder-0.4.1.0-I5KDHFCu1vgI5dETHU1xLJ
    bytestring-0.10.10.0 containers-0.6.2.1
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    mmorph-1.1.3-JCMpsrUvhnr1NOPkDZRyaY mtl-2.2.2 text-1.2.4.0
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-7SjMUGSLAdi81baGHdq4uZ

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
